==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkStructuredImplicitConnectivity.java <==
// java wrapper for vtkStructuredImplicitConnectivity object
//

package vtk;
import vtk.*;

public class vtkStructuredImplicitConnectivity extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_2(id0); }

  private native void RegisterGrid_3(int id0,int id1[],vtkPoints id2,vtkPointData id3);
  public void RegisterGrid(int id0,int id1[],vtkPoints id2,vtkPointData id3)
    { RegisterGrid_3(id0,id1,id2,id3); }

  private native void RegisterRectilinearGrid_4(int id0,int id1[],vtkDataArray id2,vtkDataArray id3,vtkDataArray id4,vtkPointData id5);
  public void RegisterRectilinearGrid(int id0,int id1[],vtkDataArray id2,vtkDataArray id3,vtkDataArray id4,vtkPointData id5)
    { RegisterRectilinearGrid_4(id0,id1,id2,id3,id4,id5); }

  private native void EstablishConnectivity_5();
  public void EstablishConnectivity()
    { EstablishConnectivity_5(); }

  private native boolean HasImplicitConnectivity_6();
  public boolean HasImplicitConnectivity()
    { return HasImplicitConnectivity_6(); }

  private native void ExchangeData_7();
  public void ExchangeData()
    { ExchangeData_7(); }

  private native void GetOutputStructuredGrid_8(int id0,vtkStructuredGrid id1);
  public void GetOutputStructuredGrid(int id0,vtkStructuredGrid id1)
    { GetOutputStructuredGrid_8(id0,id1); }

  private native void GetOutputImageData_9(int id0,vtkImageData id1);
  public void GetOutputImageData(int id0,vtkImageData id1)
    { GetOutputImageData_9(id0,id1); }

  private native void GetOutputRectilinearGrid_10(int id0,vtkRectilinearGrid id1);
  public void GetOutputRectilinearGrid(int id0,vtkRectilinearGrid id1)
    { GetOutputRectilinearGrid_10(id0,id1); }

  public vtkStructuredImplicitConnectivity() { super(); }

  public vtkStructuredImplicitConnectivity(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-aarch64.pkg.tar.xz: vtk/vtkStructuredImplicitConnectivity.java <==
// java wrapper for vtkStructuredImplicitConnectivity object
//

package vtk;
import vtk.*;

public class vtkStructuredImplicitConnectivity extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_2(id0); }

  private native void RegisterGrid_3(int id0,int id1[],vtkPoints id2,vtkPointData id3);
  public void RegisterGrid(int id0,int id1[],vtkPoints id2,vtkPointData id3)
    { RegisterGrid_3(id0,id1,id2,id3); }

  private native void RegisterRectilinearGrid_4(int id0,int id1[],vtkDataArray id2,vtkDataArray id3,vtkDataArray id4,vtkPointData id5);
  public void RegisterRectilinearGrid(int id0,int id1[],vtkDataArray id2,vtkDataArray id3,vtkDataArray id4,vtkPointData id5)
    { RegisterRectilinearGrid_4(id0,id1,id2,id3,id4,id5); }

  private native void EstablishConnectivity_5();
  public void EstablishConnectivity()
    { EstablishConnectivity_5(); }

  private native boolean HasImplicitConnectivity_6();
  public boolean HasImplicitConnectivity()
    { return HasImplicitConnectivity_6(); }

  private native void ExchangeData_7();
  public void ExchangeData()
    { ExchangeData_7(); }

  private native void GetOutputStructuredGrid_8(int id0,vtkStructuredGrid id1);
  public void GetOutputStructuredGrid(int id0,vtkStructuredGrid id1)
    { GetOutputStructuredGrid_8(id0,id1); }

  private native void GetOutputImageData_9(int id0,vtkImageData id1);
  public void GetOutputImageData(int id0,vtkImageData id1)
    { GetOutputImageData_9(id0,id1); }

  private native void GetOutputRectilinearGrid_10(int id0,vtkRectilinearGrid id1);
  public void GetOutputRectilinearGrid(int id0,vtkRectilinearGrid id1)
    { GetOutputRectilinearGrid_10(id0,id1); }

  public vtkStructuredImplicitConnectivity() { super(); }

  public vtkStructuredImplicitConnectivity(long id) { super(id); }
  public native long   VTKInit();

}
